AudioConfig class

Audio configuration builder for LLM providers

Constructors

AudioConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → Map<String, dynamic>
Get the configuration map
diarize(bool enabled) → AudioConfig
Enables diarization for STT
format(String format) → AudioConfig
Sets audio format
includeTimestamps(bool enabled) → AudioConfig
Enables timestamp inclusion
languageCode(String code) → AudioConfig
Sets language code
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
numSpeakers(int count) → AudioConfig
Sets number of speakers for diarization
quality(String quality) → AudioConfig
Sets audio quality
sampleRate(int rate) → AudioConfig
Sets sample rate
similarityBoost(double similarityBoost) → AudioConfig
Sets similarity boost parameter for ElevenLabs TTS
stability(double stability) → AudioConfig
Sets stability parameter for ElevenLabs TTS
style(double style) → AudioConfig
Sets style parameter for ElevenLabs TTS
timestampGranularity(String granularity) → AudioConfig
Sets timestamp granularity
toString() → String
A string representation of this object.
inherited
useSpeakerBoost(bool enable) → AudioConfig
Enables speaker boost for ElevenLabs TTS
voice(String voiceName) → AudioConfig
Sets voice for TTS
voiceId(String voiceId) → AudioConfig
Sets voice ID for ElevenLabs

Operators

operator ==(Object other) → bool
The equality operator.
inherited