ImageConfig class

Image generation configuration builder

Constructors

ImageConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchSize(int size) → ImageConfig
Sets batch size for generation
build() → Map<String, dynamic>
Get the configuration map
guidanceScale(double scale) → ImageConfig
Sets guidance scale
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
numInferenceSteps(int steps) → ImageConfig
Sets number of inference steps
promptEnhancement(bool enabled) → ImageConfig
Enables prompt enhancement
seed(String seed) → ImageConfig
Sets seed for reproducible generation
size(String size) → ImageConfig
Sets image size
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited