ProviderConfig class

Provider-specific configuration builder

Constructors

ProviderConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

anthropic() → ProviderConfig
Anthropic-specific configurations
build() → Map<String, dynamic>
Get the configuration map
extension(String key, dynamic value) → ProviderConfig
Add extension directly
frequencyPenalty(double penalty) → ProviderConfig
interleavedThinking(bool enable) → ProviderConfig
keepAlive(String duration) → ProviderConfig
logitBias(Map<String, double> bias) → ProviderConfig
logprobs(bool enabled) → ProviderConfig
metadata(Map<String, dynamic> data) → ProviderConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
numa(bool enabled) → ProviderConfig
numBatch(int batchSize) → ProviderConfig
numCtx(int contextLength) → ProviderConfig
numGpu(int gpuLayers) → ProviderConfig
numThread(int threads) → ProviderConfig
ollama() → ProviderConfig
Ollama-specific configurations
openai() → ProviderConfig
OpenAI-specific configurations
parallelToolCalls(bool enabled) → ProviderConfig
presencePenalty(double penalty) → ProviderConfig
raw(bool enabled) → ProviderConfig
reasoning(bool enable) → ProviderConfig
seed(int seedValue) → ProviderConfig
thinkingBudgetTokens(int tokens) → ProviderConfig
topLogprobs(int count) → ProviderConfig
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited