ChatCapability class abstract

Core chat capability interface that most LLM providers implement

API References:

Implementers

Constructors

ChatCapability()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

chat(List<ChatMessage> messages, {CancelToken? cancelToken}) → Future<ChatResponse>
Sends a chat request to the provider with a sequence of messages.
chatStream(List<ChatMessage> messages, {List<Tool>? tools, CancelToken? cancelToken}) → Stream<ChatStreamEvent>
Sends a streaming chat request to the provider
chatWithTools(List<ChatMessage> messages, List<Tool>? tools, {CancelToken? cancelToken}) → Future<ChatResponse>
Sends a chat request to the provider with a sequence of messages and tools.
memoryContents() → Future<List<ChatMessage>?>
Get current memory contents if provider supports memory
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
summarizeHistory(List<ChatMessage> messages) → Future<String>
Summarizes a conversation history into a concise 2-3 sentence summary
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited