ChatResponse class abstract

Response from a chat provider

Implementers

Constructors

ChatResponse()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
Get the text content of the response
no setter
thinking → String?
Get thinking/reasoning content (for providers that support it)
no setter
toolCalls → List<ToolCall>?
Get tool calls from the response
no setter
usage → UsageInfo?
Get usage information if available
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited