CompletionRequest class

Completion request for text completion providers

Constructors

CompletionRequest({required String prompt, int? maxTokens, double? temperature, double? topP, int? topK, List<String>? stop})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxTokens → int?
final
prompt → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stop → List<String>?
final
temperature → double?
final
topK → int?
final
topP → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited