EmbeddingCapability class abstract

Capability interface for vector embeddings

Implementers

Constructors

EmbeddingCapability()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

embed(List<String> input, {CancelToken? cancelToken}) → Future<List<List<double>>>
Generate embeddings for the given input texts
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited