FileManagementCapability class abstract

File management capability for uploading and managing files

This interface provides a unified API for file operations across different providers (OpenAI, Anthropic, etc.).

Implementers

Constructors

FileManagementCapability()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteFile(String fileId) → Future<FileDeleteResponse>
Delete a file
getFileContent(String fileId) → Future<List<int>>
Get file content
listFiles([FileListQuery? query]) → Future<FileListResponse>
List files
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retrieveFile(String fileId) → Future<FileObject>
Retrieve file metadata
toString() → String
A string representation of this object.
inherited
uploadFile(FileUploadRequest request) → Future<FileObject>
Upload a file

Operators

operator ==(Object other) → bool
The equality operator.
inherited