FullLLMProvider class abstract

Full-featured LLM provider with all common capabilities

Implemented types

Constructors

FullLLMProvider()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedCapabilities → Set<LLMCapability>
Set of capabilities this provider supports
no setterinherited

Methods

chat(List<ChatMessage> messages, {CancelToken? cancelToken}) → Future<ChatResponse>
Sends a chat request to the provider with a sequence of messages.
inherited
chatStream(List<ChatMessage> messages, {List<Tool>? tools, CancelToken? cancelToken}) → Stream<ChatStreamEvent>
Sends a streaming chat request to the provider
inherited
chatWithTools(List<ChatMessage> messages, List<Tool>? tools, {CancelToken? cancelToken}) → Future<ChatResponse>
Sends a chat request to the provider with a sequence of messages and tools.
inherited
embed(List<String> input, {CancelToken? cancelToken}) → Future<List<List<double>>>
Generate embeddings for the given input texts
inherited
memoryContents() → Future<List<ChatMessage>?>
Get current memory contents if provider supports memory
inherited
models({CancelToken? cancelToken}) → Future<List<AIModel>>
Get available models from the provider
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
summarizeHistory(List<ChatMessage> messages) → Future<String>
Summarizes a conversation history into a concise 2-3 sentence summary
inherited
supports(LLMCapability capability) → bool
Check if this provider supports a specific capability
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited