ImageGenerationCapability class abstract

Capability interface for image generation

Supports image generation, editing, and variation creation across different providers. Reference: https://platform.openai.com/docs/api-reference/images

Implementers

Constructors

ImageGenerationCapability()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsImageEditing → bool
Check if the provider supports image editing
no setter
supportsImageVariations → bool
Check if the provider supports image variations
no setter

Methods

createVariation(ImageVariationRequest request) → Future<ImageGenerationResponse>
Create variations of an existing image
editImage(ImageEditRequest request) → Future<ImageGenerationResponse>
Edit an existing image based on a prompt
generateImage({required String prompt, String? model, String? negativePrompt, String? imageSize, int? batchSize, String? seed, int? numInferenceSteps, double? guidanceScale, bool? promptEnhancement}) → Future<List<String>>
Simple image generation (convenience method)
generateImages(ImageGenerationRequest request) → Future<ImageGenerationResponse>
Generate images from text prompts
getSupportedFormats() → List<String>
Get supported response formats for this provider
getSupportedSizes() → List<String>
Get supported image sizes for this provider
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited