ModelListingCapability class abstract

Capability interface for model listing

Implementers

Constructors

ModelListingCapability()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

models({CancelToken? cancelToken}) → Future<List<AIModel>>
Get available models from the provider
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited