RealtimeAudioConfig class

Configuration for real-time audio sessions

Constructors

RealtimeAudioConfig({String? inputFormat, String? outputFormat, int? sampleRate, bool enableVAD = true, bool enableEchoCancellation = true, bool enableNoiseSuppression = true, int? timeoutSeconds, Map<String, dynamic>? customParams})
const
RealtimeAudioConfig.fromJson(Map<String, dynamic> json)
factory

Properties

customParams → Map<String, dynamic>?
Custom session parameters
final
enableEchoCancellation → bool
Enable echo cancellation
final
enableNoiseSuppression → bool
Enable noise suppression
final
enableVAD → bool
Enable voice activity detection
final
hashCode → int
The hash code for this object.
no setterinherited
inputFormat → String?
Audio input format
final
outputFormat → String?
Audio output format
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRate → int?
Sample rate for audio processing
final
timeoutSeconds → int?
Session timeout in seconds
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited