RealtimeAudioSession class abstract

A stateful real-time audio session

Constructors

RealtimeAudioSession()

Properties

events → Stream<RealtimeAudioEvent>
Receive events from the session
no setter
hashCode → int
The hash code for this object.
no setterinherited
isActive → bool
Check if the session is still active
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String
Session ID for tracking
no setter

Methods

close() → Future<void>
Close the session gracefully
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendAudio(List<int> audioData) → void
Send audio data to the session
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited