RealtimeErrorEvent class

Real-time error event

Inheritance

Constructors

RealtimeErrorEvent({required DateTime timestamp, required String message, String? code})
const

Properties

code → String?
Error code
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
Error message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
Timestamp of the event
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited