RealtimeTranscriptionEvent class

Real-time transcription event

Inheritance

Constructors

RealtimeTranscriptionEvent({required DateTime timestamp, required String text, required bool isFinal, double? confidence})
const

Properties

confidence → double?
Confidence score
final
hashCode → int
The hash code for this object.
no setterinherited
isFinal → bool
Whether this is a final transcription
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
Transcribed text
final
timestamp → DateTime
Timestamp of the event
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited