ToolExecutionCapability class abstract

Tool execution capability for providers that support client-side tool execution

This capability allows providers to execute tools locally and return results to the model for further processing.

Constructors

ToolExecutionCapability()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolExecutors → Map<String, Future<ToolResult> Function(ToolCall toolCall)>
Get registered tool executors
no setter

Methods

executeTool(ToolCall toolCall) → Future<ToolResult>
Execute a single tool call
executeToolsParallel(List<ToolCall> toolCalls, {ParallelToolConfig? config}) → Future<List<ToolResult>>
Execute multiple tools in parallel and return results
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerToolExecutor(String toolName, Future<ToolResult> executor(ToolCall toolCall)) → void
Register a tool executor function
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited