ModelCapabilityConfig class

Model-specific capability configuration

Constructors

ModelCapabilityConfig({bool supportsReasoning = false, bool supportsVision = false, bool supportsToolCalling = true, int? maxContextLength, bool disableTemperature = false, bool disableTopP = false, Map<String, dynamic>? reasoningEffortMapping})
const

Properties

disableTemperature → bool
Whether temperature should be disabled for this model
final
disableTopP → bool
Whether top_p should be disabled for this model
final
hashCode → int
The hash code for this object.
no setterinherited
maxContextLength → int?
Maximum context length for this model
final
reasoningEffortMapping → Map<String, dynamic>?
Custom reasoning effort mapping for this model
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsReasoning → bool
Whether this model supports reasoning/thinking
final
supportsToolCalling → bool
Whether this model supports tool calling
final
supportsVision → bool
Whether this model supports vision/image input
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited