RequestBodyTransformer class abstract

Abstract interface for transforming request body for provider-specific parameters

Implementers

Constructors

RequestBodyTransformer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transform(Map<String, dynamic> body, LLMConfig config, OpenAICompatibleProviderConfig providerConfig) → Map<String, dynamic>
Transform the request body to include provider-specific parameters

Operators

operator ==(Object other) → bool
The equality operator.
inherited