GoogleTransformers class

Factory for creating Google transformers

Constructors

GoogleTransformers()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createHeadersTransformer() → HeadersTransformer
Create headers transformer for Google
createRequestBodyTransformer() → RequestBodyTransformer
Create request body transformer for Google
createTransformers() → (RequestBodyTransformer, HeadersTransformer)
Create both transformers for Google