OpenAIResponsesError class

OpenAI Responses API specific error

Inheritance

Constructors

OpenAIResponsesError(String message, {String? responseId, String? errorType})
const

Properties

errorType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
responseId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited