StructuredOutputError class

Structured output validation error

Inheritance

Constructors

StructuredOutputError(String message, {String? schemaName, Map<String, dynamic>? schema, String? actualOutput})
const

Properties

actualOutput → String?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → Map<String, dynamic>?
final
schemaName → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited