ToolExecutionError class

Tool execution error

Inheritance

Constructors

ToolExecutionError(String message, {required String toolName, String? toolId, Map<String, dynamic>? toolArguments})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolArguments → Map<String, dynamic>?
final
toolId → String?
final
toolName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited