ToolValidationError class

Tool validation error

Inheritance

Constructors

ToolValidationError(String message, {required String toolName, String? parameterName, dynamic providedValue, String? expectedType})
const

Properties

expectedType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
parameterName → String?
final
providedValue → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited