UnsupportedCapabilityError class

Unsupported capability error

Thrown when trying to build a provider with a capability it doesn't support. This is used by the capability factory methods in LLMBuilder.

Inheritance

Constructors

UnsupportedCapabilityError(String message, {String? providerId, String? capabilityName, List<String>? supportedProviders})
const

Properties

capabilityName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
providerId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedProviders → List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited