ProviderInfo class

Information about a registered provider

Constructors

ProviderInfo({required String id, required String displayName, required String description, required Set<LLMCapability> supportedCapabilities, required LLMConfig defaultConfig})
const

Properties

defaultConfig → LLMConfig
Default configuration for this provider
final
description → String
Provider description
final
displayName → String
Human-readable display name
final
hashCode → int
The hash code for this object.
no setteroverride
id → String
Unique provider ID
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedCapabilities → Set<LLMCapability>
Set of capabilities this provider supports
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supports(LLMCapability capability) → bool
Check if this provider supports a capability
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override