WebSearchLocation class

Geographic location for search localization

Constructors

WebSearchLocation({String? city, String? region, String? country, String? timezone, String? type = 'approximate'})
const
WebSearchLocation.london()
Create location for London
factory
WebSearchLocation.sanFrancisco()
Create location for San Francisco
factory
WebSearchLocation.tokyo()
Create location for Tokyo
factory
WebSearchLocation.newYork()
Create location for New York
factory

Properties

city → String?
City name
final
country → String?
Country name or code
final
hashCode → int
The hash code for this object.
no setterinherited
region → String?
State/region name
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timezone → String?
IANA timezone identifier
final
type → String?
Location type (e.g., "approximate")
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited