Assistant class

Represents an assistant that can call the model and use tools.

Constructors

Assistant({required String id, String object = 'assistant', required int createdAt, String? name, String? description, required String model, String? instructions, List<AssistantTool> tools = const [], ToolResources? toolResources, Map<String, String>? metadata, double? temperature, double? topP, AssistantResponseFormat? responseFormat})
const
Assistant.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → int
The Unix timestamp (in seconds) for when the assistant was created.
final
description → String?
The description of the assistant.
final
hashCode → int
The hash code for this object.
no setteroverride
id → String
The identifier, which can be referenced in API endpoints.
final
instructions → String?
The system instructions that the assistant uses.
final
metadata → Map<String, String>?
Set of 16 key-value pairs that can be attached to an object.
final
model → String
ID of the model to use.
final
name → String?
The name of the assistant.
final
object → String
The object type, which is always assistant.
final
responseFormat → AssistantResponseFormat?
Specifies the format that the model must output.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
temperature → double?
What sampling temperature to use, between 0 and 2.
final
toolResources → ToolResources?
A set of resources that are used by the assistant's tools.
final
tools → List<AssistantTool>
A list of tool enabled on the assistant.
final
topP → double?
An alternative to sampling with temperature, called nucleus sampling.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override