AssistantResponseFormat class

Response format for assistants

Constructors

AssistantResponseFormat({required String type, Map<String, dynamic>? jsonSchema})
const
AssistantResponseFormat.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
jsonSchema → Map<String, dynamic>?
The JSON schema for the response format.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Must be one of text or json_object or json_schema.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited