DeleteAssistantResponse class

Response for deleting an assistant

Constructors

DeleteAssistantResponse({required String id, String object = 'assistant.deleted', required bool deleted})
const
DeleteAssistantResponse.fromJson(Map<String, dynamic> json)
factory

Properties

deleted → bool
Whether the assistant was successfully deleted.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The identifier of the deleted assistant.
final
object → String
The object type, which is always "assistant.deleted".
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited