FileSearchResources class

File search resources

Constructors

FileSearchResources({List<String>? vectorStoreIds, List<VectorStoreRequest>? vectorStores})
const
FileSearchResources.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vectorStoreIds → List<String>?
The vector store attached to this assistant.
final
vectorStores → List<VectorStoreRequest>?
A helper to create a vector store with file_ids and attach it to this assistant.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited