ToolResources class

Tool resources for assistants

Constructors

ToolResources({CodeInterpreterResources? codeInterpreter, FileSearchResources? fileSearch})
const
ToolResources.fromJson(Map<String, dynamic> json)
factory

Properties

codeInterpreter → CodeInterpreterResources?
Resources for the code interpreter tool
final
fileSearch → FileSearchResources?
Resources for the file search tool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited