VectorStoreRequest class

Vector store request for creating vector stores

Constructors

VectorStoreRequest({List<String>? fileIds, Map<String, dynamic>? chunkingStrategy, Map<String, String>? metadata})
const
VectorStoreRequest.fromJson(Map<String, dynamic> json)
factory

Properties

chunkingStrategy → Map<String, dynamic>?
The chunking strategy used to chunk the file(s).
final
fileIds → List<String>?
A list of file IDs to add to the vector store.
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, String>?
Set of 16 key-value pairs that can be attached to a vector store.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited