AudioAlignment class

Character-level timing alignment for TTS (ElevenLabs specific)

Constructors

AudioAlignment({required List<String> characters, required List<double> characterStartTimes, required List<double> characterEndTimes})
const
AudioAlignment.fromJson(Map<String, dynamic> json)
factory

Properties

characterEndTimes → List<double>
End times for each character in seconds
final
characters → List<String>
List of characters
final
characterStartTimes → List<double>
Start times for each character in seconds
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited