AudioFormat enum

Audio format enumeration for better type safety

Inheritance
Available extensions

Values

mp3 → const AudioFormat

MP3 format

wav → const AudioFormat

WAV format

ogg → const AudioFormat

OGG format

opus → const AudioFormat

OPUS format

aac → const AudioFormat

AAC format

flac → const AudioFormat

FLAC format

pcm → const AudioFormat

PCM format

webm → const AudioFormat

WebM format

m4a → const AudioFormat

M4A format

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
mimeType → String

Available on AudioFormat, provided by the AudioFormatExtension extension

Get MIME type for the audio format
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String

Available on AudioFormat, provided by the AudioFormatExtension extension

Get the string representation of the audio format
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<AudioFormat>
A constant List of the values in this enum, in order of their declaration.