AudioMetadataEvent class

Audio metadata event

Inheritance

Constructors

AudioMetadataEvent({String? contentType, int? sampleRate, double? duration})
const

Properties

contentType → String?
Content type
final
duration → double?
Duration in seconds
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRate → int?
Sample rate
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited