AudioTimingEvent class

Audio timing event for character-level alignment

Inheritance

Constructors

AudioTimingEvent({required String character, required double startTime, required double endTime})
const

Properties

character → String
Character being spoken
final
endTime → double
End time in seconds
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → double
Start time in seconds
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited