AudioTranslationRequest class

Audio translation request (OpenAI specific)

Constructors

AudioTranslationRequest({List<int>? audioData, String? filePath, String? model, String? format, String? prompt, String? responseFormat, double? temperature})
const
AudioTranslationRequest.fromAudio(List<int> audioData, {String? model, String? format, String? prompt, String? responseFormat, double? temperature})
Create translation request from audio data
factory
AudioTranslationRequest.fromFile(String filePath, {String? model, String? format, String? prompt, String? responseFormat, double? temperature})
Create translation request from file
factory
AudioTranslationRequest.fromJson(Map<String, dynamic> json)
factory

Properties

audioData → List<int>?
Audio data as bytes (for direct audio input)
final
filePath → String?
File path (for file input)
final
format → String?
Audio format hint
final
hashCode → int
The hash code for this object.
no setterinherited
model → String?
Model to use for translation
final
prompt → String?
Prompt to guide translation style
final
responseFormat → String?
Response format (json, text, srt, verbose_json, vtt)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
temperature → double?
Temperature for translation (0.0-1.0)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited