EnhancedWordTiming class

Enhanced word timing with speaker information (ElevenLabs specific)

Inheritance

Constructors

EnhancedWordTiming({required String word, required double start, required double end, double? confidence, String? type, double? logprob, String? speakerId})
const
EnhancedWordTiming.fromJson(Map<String, dynamic> json)
factory

Properties

confidence → double?
Confidence score for this word (0.0-1.0)
finalinherited
end → double
End time in seconds
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
logprob → double?
Log probability of the word
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speakerId → String?
Speaker ID if diarization is enabled
final
start → double
Start time in seconds
finalinherited
type → String?
Type of the word (word, spacing, punctuation)
final
word → String
The word text
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited