LanguageInfo class

Language information for STT

Constructors

LanguageInfo({required String code, required String name, bool supportsRealtime = false})
const
LanguageInfo.fromJson(Map<String, dynamic> json)
factory

Properties

code → String
Language code (e.g., 'en-US')
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Language name
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsRealtime → bool
Whether this language is supported for real-time STT
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited