STTResponse class

Speech-to-Text response with metadata

Constructors

STTResponse({required String text, String? language, double? confidence, List<WordTiming>? words, List<TranscriptionSegment>? segments, String? model, double? duration, UsageInfo? usage, double? languageProbability, Map<String, dynamic>? additionalFormats})
const
STTResponse.fromJson(Map<String, dynamic> json)
factory

Properties

additionalFormats → Map<String, dynamic>?
Additional formats (ElevenLabs specific)
final
confidence → double?
Overall confidence score (0.0-1.0)
final
duration → double?
Audio duration in seconds
final
hashCode → int
The hash code for this object.
no setterinherited
language → String?
Language code detected
final
languageProbability → double?
Language probability (ElevenLabs specific)
final
model → String?
Model used for transcription
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segments → List<TranscriptionSegment>?
Segment-level information (OpenAI specific)
final
text → String
Transcribed text
final
usage → UsageInfo?
Usage information if available
final
words → List<WordTiming>?
Word-level timing and confidence information
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited