VoiceInfo class

Voice information

Constructors

VoiceInfo({required String id, required String name, String? description, String? category, String? gender, String? accent, String? previewUrl})
const
VoiceInfo.fromJson(Map<String, dynamic> json)
factory

Properties

accent → String?
Voice accent/language
final
category → String?
Voice category (e.g., 'premade', 'cloned')
final
description → String?
Voice description
final
gender → String?
Voice gender
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Voice ID
final
name → String
Voice name
final
previewUrl → String?
Preview URL if available
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited