WordTiming class

Word timing information for STT

Implementers

Constructors

WordTiming({required String word, required double start, required double end, double? confidence})
const
WordTiming.fromJson(Map<String, dynamic> json)
factory

Properties

confidence → double?
Confidence score for this word (0.0-1.0)
final
end → double
End time in seconds
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → double
Start time in seconds
final
word → String
The word text
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited