AIModel class

Represents an AI model with its metadata

Constructors

AIModel({required String id, String? description, String object = 'model', String? ownedBy})
const
AIModel.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
Human-readable description of the model
final
hashCode → int
The hash code for this object.
no setteroverride
id → String
The unique identifier of the model
final
object → String
The object type (typically "model")
final
ownedBy → String?
The organization that owns the model
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override