FileMime class

General MIME type for files

Constructors

FileMime(String mimeType)
const

Properties

description → String
Get a human-readable description of the file type
no setter
hashCode → int
The hash code for this object.
no setteroverride
isArchive → bool
Check if this is an archive type
no setter
isAudio → bool
Check if this is an audio type
no setter
isDocument → bool
Check if this is a document type
no setter
isVideo → bool
Check if this is a video type
no setter
mimeType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

avi → const FileMime
csv → const FileMime
doc → const FileMime
docx → const FileMime
gif → const FileMime
gz → const FileMime
jpeg → const FileMime
json → const FileMime
m4a → const FileMime
mov → const FileMime
mp3 → const FileMime
mp4 → const FileMime
ogg → const FileMime
pdf → const FileMime
png → const FileMime
ppt → const FileMime
pptx → const FileMime
rar → const FileMime
tar → const FileMime
txt → const FileMime
wav → const FileMime
webm → const FileMime
webp → const FileMime
xls → const FileMime
xlsx → const FileMime
xml → const FileMime
zip → const FileMime