ReasoningEffort enum

Reasoning effort levels for models that support reasoning

Inheritance
Available extensions

Values

minimal → const ReasoningEffort
low → const ReasoningEffort
medium → const ReasoningEffort
high → const ReasoningEffort

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
Convert to string value for API requests
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromString(String? value) → ReasoningEffort?
Create from string value

Constants

values → const List<ReasoningEffort>
A constant List of the values in this enum, in order of their declaration.