ToolCall class

Tool call represents a function call that an LLM wants to make.

Constructors

ToolCall({required String id, required String callType, required FunctionCall function})
const
ToolCall.fromJson(Map<String, dynamic> json)
factory

Properties

callType → String
The type of the tool call (usually "function").
final
function → FunctionCall
The function to call.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The ID of the tool call.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited