ToolsBlock class

Tools block for storing tools in messages This allows tools to be cached and processed by providers

Implemented types

Constructors

ToolsBlock(List<Tool> tools)

Properties

displayText → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
providerId → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tools → List<Tool>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited