FileListQuery class

File list query parameters that work across providers

Constructors

FileListQuery({FilePurpose? purpose, int? limit, String? order, String? after, String? beforeId, String? afterId})
const

Properties

after → String?
A cursor for use in pagination (OpenAI style).
final
afterId → String?
final
beforeId → String?
Cursor-based pagination (Anthropic style).
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int?
A limit on the number of objects to be returned.
final
order → String?
Sort order by the created_at timestamp of the objects (OpenAI).
final
purpose → FilePurpose?
Only return files with the given purpose (OpenAI).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAnthropicQueryParameters() → Map<String, String>
Convert to Anthropic query parameters
toOpenAIQueryParameters() → Map<String, dynamic>
Convert to OpenAI query parameters
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited