FileListResponse class

File list response that works across providers

Constructors

FileListResponse({required List<FileObject> data, String object = 'list', String? firstId, String? lastId, bool? hasMore, int? total, int? limit, int? offset})
const
FileListResponse.fromAnthropic(Map<String, dynamic> json)
Create from Anthropic format
factory
FileListResponse.fromOpenAI(Map<String, dynamic> json)
Create from OpenAI format
factory

Properties

data → List<FileObject>
The list of files.
final
firstId → String?
Pagination information for cursor-based pagination (Anthropic style).
final
hashCode → int
The hash code for this object.
no setterinherited
hasMore → bool?
final
lastId → String?
final
limit → int?
final
object → String
The object type.
final
offset → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → int?
Pagination information for offset-based pagination (OpenAI style).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAnthropicJson() → Map<String, dynamic>
Convert to Anthropic format
toOpenAIJson() → Map<String, dynamic>
Convert to OpenAI format
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited