FileUploadRequest class

File upload request that works across providers

Constructors

FileUploadRequest({required Uint8List file, required String filename, FilePurpose? purpose, Map<String, dynamic>? metadata})
const

Properties

file → Uint8List
The file to upload.
final
filename → String
The name of the file to upload.
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, dynamic>?
Additional metadata for the file upload.
final
purpose → FilePurpose?
The intended purpose of the uploaded file (may be null for providers that don't support it).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAnthropicJson() → Map<String, dynamic>
Convert to Anthropic format
toOpenAIJson() → Map<String, dynamic>
Convert to OpenAI format
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited