GeneratedImage class

Generated image information

Constructors

GeneratedImage({String? url, List<int>? data, String? revisedPrompt, String? format, ImageDimensions? dimensions})
const
GeneratedImage.fromJson(Map<String, dynamic> json)
factory

Properties

data → List<int>?
Image data as bytes (for direct data responses)
final
dimensions → ImageDimensions?
Image dimensions
final
format → String?
Image format (png, jpeg, webp, etc.)
final
hashCode → int
The hash code for this object.
no setterinherited
revisedPrompt → String?
Revised prompt for this specific image
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
Image URL (for URL-based responses)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited