ImageEditRequest class

Constructors

ImageEditRequest({required ImageInput image, required String prompt, ImageInput? mask, String? model, int? count, String? size, String? responseFormat, String? user})
const
ImageEditRequest.fromJson(Map<String, dynamic> json)
factory

Properties

count → int?
The number of images to generate. Must be between 1 and 10.
final
hashCode → int
The hash code for this object.
no setterinherited
image → ImageInput
The image to edit. Must be a valid PNG file, less than 4MB, and square. If mask is not provided, image must have transparency, which will be used as the mask.
final
mask → ImageInput?
An additional image whose fully transparent areas (e.g. where alpha is zero) indicate where image should be edited. Must be a valid PNG file, less than 4MB, and have the same dimensions as image.
final
model → String?
The model to use for image generation. Only dall-e-2 is supported at this time.
final
prompt → String
A text description of the desired image(s). The maximum length is 1000 characters.
final
responseFormat → String?
The format in which the generated images are returned. Must be one of url or b64_json.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → String?
The size of the generated images. Must be one of 256x256, 512x512, or 1024x1024.
final
user → String?
A unique identifier representing your end-user, which will help OpenAI to monitor and detect abuse.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited