ImageGenerationResponse class

Image generation response with metadata

Constructors

ImageGenerationResponse({required List<GeneratedImage> images, String? model, String? revisedPrompt, UsageInfo? usage})
const
ImageGenerationResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
images → List<GeneratedImage>
Generated image URLs or data
final
model → String?
Model used for generation
final
revisedPrompt → String?
Revised prompt (if prompt enhancement was used)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usage → UsageInfo?
Usage information if available
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited