ImageSize class

Common image sizes for generation

Constructors

ImageSize()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

allSizes → List<String>
Get all available standard sizes
no setter

Static Methods

isLandscape(String size) → bool
Check if size is landscape
isPortrait(String size) → bool
Check if size is portrait
isSquare(String size) → bool
Check if size is square
parseDimensions(String size) → ImageDimensions?
Parse size string to dimensions