ImageVariationRequest class

Constructors

ImageVariationRequest({required ImageInput image, String? model, int? count, String? size, String? responseFormat, String? user})
const
ImageVariationRequest.fromJson(Map<String, dynamic> json)
factory

Properties

count → int?
The number of images to generate. Must be between 1 and 10.
final
hashCode → int
The hash code for this object.
no setterinherited
image → ImageInput
The image to use as the basis for the variation(s). Must be a valid PNG file, less than 4MB, and square.
final
model → String?
The model to use for image generation. Only dall-e-2 is supported at this time.
final
responseFormat → String?
The format in which the generated images are returned. Must be one of url or b64_json.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → String?
The size of the generated images. Must be one of 256x256, 512x512, or 1024x1024.
final
user → String?
A unique identifier representing your end-user, which will help OpenAI to monitor and detect abuse.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited