ModerationResponse class

Response from the moderation API

Constructors

ModerationResponse({required String id, required String model, required List<ModerationResult> results})
const
ModerationResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier for the moderation request.
final
model → String
The model used to generate the moderation results.
final
results → List<ModerationResult>
A list of moderation objects.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited