ModerationResult class

A single moderation result

Constructors

ModerationResult({required bool flagged, required ModerationCategories categories, required ModerationCategoryScores categoryScores})
const
ModerationResult.fromJson(Map<String, dynamic> json)
factory

Properties

categories → ModerationCategories
A list of the categories, and whether they are flagged or not.
final
categoryScores → ModerationCategoryScores
A list of the categories along with their scores as predicted by model.
final
flagged → bool
Whether any of the below categories are flagged.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited