ResponseInputItem class

Individual input item in a response

Constructors

ResponseInputItem({required String id, required String type, String? role, List<Map<String, dynamic>>? content})
const
ResponseInputItem.fromJson(Map<String, dynamic> json)
factory

Properties

content → List<Map<String, dynamic>>?
Content of the input item
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier for the input item
final
role → String?
Role of the message (for message type items)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Type of input item (e.g., 'message')
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited