ResponseInputItemsList class

Response input items list for Responses API

Constructors

ResponseInputItemsList({required String object, required List<ResponseInputItem> data, String? firstId, String? lastId, required bool hasMore})
const
ResponseInputItemsList.fromJson(Map<String, dynamic> json)
factory

Properties

data → List<ResponseInputItem>
List of input items
final
firstId → String?
ID of the first item in the list
final
hashCode → int
The hash code for this object.
no setterinherited
hasMore → bool
Whether there are more items available
final
lastId → String?
ID of the last item in the list
final
object → String
The type of object returned, always 'list'
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited