FunctionObject class

Represents a function object for assistants (similar to FunctionTool but with optional parameters)

Constructors

FunctionObject({required String name, String? description, Map<String, dynamic>? parameters, bool? strict})
const
FunctionObject.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
Description of what the function does
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the function
final
parameters → Map<String, dynamic>?
The parameters schema for the function (optional for assistants)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strict → bool?
Whether to enable strict schema adherence
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited