NoneToolChoice class

Explicitly disables the use of tools. The model will not use any tools even if they are provided.

Maps to:

  • OpenAI: {"type": "none"}
  • Anthropic: "none"
  • xAI: {"type": "none"}
Inheritance

Constructors

NoneToolChoice()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAnthropicJson() → String
Convert to Anthropic format
override
toJson() → Map<String, dynamic>
override
toOpenAIJson() → Map<String, dynamic>
Convert to OpenAI format
inherited
toString() → String
A string representation of this object.
inherited
toXAIJson() → Map<String, dynamic>
Convert to xAI format (OpenAI-compatible)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited