ParallelToolConfig class

Parallel tool execution configuration

Constructors

ParallelToolConfig({int maxParallel = 5, Duration? toolTimeout, bool continueOnError = true})
const
ParallelToolConfig.fromJson(Map<String, dynamic> json)
factory

Properties

continueOnError → bool
Whether to continue execution if one tool fails
final
hashCode → int
The hash code for this object.
no setterinherited
maxParallel → int
Maximum number of tools to execute in parallel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolTimeout → Duration?
Timeout for individual tool execution
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited