ParameterProperty class

Represents a parameter in a function tool

Constructors

ParameterProperty({required String propertyType, required String description, ParameterProperty? items, List<String>? enumList, Map<String, ParameterProperty>? properties, List<String>? required})
const
ParameterProperty.fromJson(Map<String, dynamic> json)
factory

Properties

description → String
Description of what the parameter does
final
enumList → List<String>?
When type is "enum", this defines the possible values for the parameter
final
hashCode → int
The hash code for this object.
no setterinherited
items → ParameterProperty?
When type is "array", this defines the type of the array items
final
properties → Map<String, ParameterProperty>?
When type is "object", this defines the properties of the object
final
propertyType → String
The type of the parameter (e.g. "string", "number", "array", etc)
final
required → List<String>?
When type is "object", this defines which properties are required
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited