ParametersSchema class

Represents the parameters schema for a function tool

Constructors

ParametersSchema({required String schemaType, required Map<String, ParameterProperty> properties, required List<String> required})
const
ParametersSchema.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
properties → Map<String, ParameterProperty>
Map of parameter names to their properties
final
required → List<String>
List of required parameter names
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaType → String
The type of the parameters object (usually "object")
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited