ToolChoice class sealed

Tool choice determines how the LLM uses available tools. The behavior is standardized across different LLM providers.

API References:

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAnthropicJson() → String
Convert to Anthropic format
toJson() → Map<String, dynamic>
toOpenAIJson() → Map<String, dynamic>
Convert to OpenAI format
toString() → String
A string representation of this object.
inherited
toXAIJson() → Map<String, dynamic>
Convert to xAI format (OpenAI-compatible)

Operators

operator ==(Object other) → bool
The equality operator.
inherited