GoogleChat class

Google Chat capability implementation

This module handles all chat-related functionality for Google providers, including streaming, tool calling, and reasoning model support.

Implemented types

Constructors

GoogleChat(GoogleClient client, GoogleConfig config)

Properties

client → GoogleClient
final
config → GoogleConfig
final
generateContentEndpoint → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamGenerateContentEndpoint → String
no setter

Methods

chat(List<ChatMessage> messages, {CancelToken? cancelToken}) → Future<ChatResponse>
Sends a chat request to the provider with a sequence of messages.
override
chatStream(List<ChatMessage> messages, {List<Tool>? tools, CancelToken? cancelToken}) → Stream<ChatStreamEvent>
Sends a streaming chat request to the provider
override
chatWithTools(List<ChatMessage> messages, List<Tool>? tools, {CancelToken? cancelToken}) → Future<ChatResponse>
Sends a chat request to the provider with a sequence of messages and tools.
override
getOrUploadFile({required List<int> data, required String mimeType, required String displayName}) → Future<GoogleFile?>
Get or upload a file, using cache when possible
memoryContents() → Future<List<ChatMessage>?>
Get current memory contents if provider supports memory
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
summarizeHistory(List<ChatMessage> messages) → Future<String>
Summarizes a conversation history into a concise 2-3 sentence summary
override
toString() → String
A string representation of this object.
inherited
uploadFile({required List<int> data, required String mimeType, required String displayName}) → Future<GoogleFile>
Upload a file to Google AI Files API

Operators

operator ==(Object other) → bool
The equality operator.
inherited