GoogleFile class

Google file upload response

Constructors

GoogleFile({required String name, required String displayName, required String mimeType, required int sizeBytes, required String state, String? uri})
const
GoogleFile.fromJson(Map<String, dynamic> json)
factory

Properties

displayName → String
final
hashCode → int
The hash code for this object.
no setterinherited
isActive → bool
no setter
mimeType → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes → int
final
state → String
final
uri → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited