SafetySetting class

Google AI safety setting

Constructors

SafetySetting({required HarmCategory category, required HarmBlockThreshold threshold})
const

Properties

category → HarmCategory
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threshold → HarmBlockThreshold
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited