GooglePrebuiltVoiceConfig class

Google prebuilt voice configuration

Constructors

GooglePrebuiltVoiceConfig({required String voiceName})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
voiceName → String
Voice name (e.g., 'Kore', 'Puck', 'Zephyr')
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited