GoogleTTSAudioDataEvent class

Google TTS audio data event

Inheritance

Constructors

GoogleTTSAudioDataEvent({required List<int> data, bool isFinal = false})
const

Properties

data → List<int>
Audio data chunk
final
hashCode → int
The hash code for this object.
no setterinherited
isFinal → bool
Whether this is the final chunk
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited