GoogleTTSMetadataEvent class

Google TTS metadata event

Inheritance

Constructors

GoogleTTSMetadataEvent({String? contentType, String? model, UsageInfo? usage})
const

Properties

contentType → String?
Content type
final
hashCode → int
The hash code for this object.
no setterinherited
model → String?
Model used
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usage → UsageInfo?
Usage information
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited