OpenAIChat class

OpenAI Chat capability implementation

This module handles all chat-related functionality for OpenAI providers, including streaming, tool calling, and reasoning model support.

Implemented types

Constructors

OpenAIChat(OpenAIClient client, OpenAIConfig config)

Properties

chatEndpoint → String
no setter
client → OpenAIClient
final
config → OpenAIConfig
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

chat(List<ChatMessage> messages, {CancelToken? cancelToken}) → Future<ChatResponse>
Sends a chat request to the provider with a sequence of messages.
override
chatStream(List<ChatMessage> messages, {List<Tool>? tools, CancelToken? cancelToken}) → Stream<ChatStreamEvent>
Sends a streaming chat request to the provider
override
chatWithTools(List<ChatMessage> messages, List<Tool>? tools, {CancelToken? cancelToken}) → Future<ChatResponse>
Sends a chat request to the provider with a sequence of messages and tools.
override
memoryContents() → Future<List<ChatMessage>?>
Get current memory contents if provider supports memory
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
summarizeHistory(List<ChatMessage> messages) → Future<String>
Summarizes a conversation history into a concise 2-3 sentence summary
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited