PhindClient class

Phind HTTP client implementation

This module handles all HTTP communication with the Phind API. Phind has a unique API format that requires special handling.

Constructors

PhindClient(PhindConfig config)

Properties

config → PhindConfig
final
hashCode → int
The hash code for this object.
no setterinherited
logger → Logger
Logger instance for debugging
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postJson(String endpoint, Map<String, dynamic> data, {CancelToken? cancelToken}) → Future<Map<String, dynamic>>
Make a POST request and return JSON response
postStreamRaw(String endpoint, Map<String, dynamic> data, {CancelToken? cancelToken}) → Stream<String>
Make a POST request and return raw stream
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited