PhindConfig class

Phind provider configuration

This class contains all configuration options for the Phind providers. Phind is a coding-focused AI assistant with specialized models.

Constructors

PhindConfig({required String apiKey, String baseUrl = 'https://https.extension.phind.com/agent/', String model = 'Phind-70B', int? maxTokens, double? temperature, String? systemPrompt, Duration? timeout, double? topP, int? topK, List<Tool>? tools, ToolChoice? toolChoice, LLMConfig? originalConfig})
const
PhindConfig.fromLLMConfig(LLMConfig config)
Create PhindConfig from unified LLMConfig
factory

Properties

apiKey → String
final
baseUrl → String
final
hashCode → int
The hash code for this object.
no setterinherited
maxTokens → int?
final
model → String
final
modelFamily → String
Get the model family
no setter
originalConfig → LLMConfig?
Get the original LLMConfig for HTTP configuration
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsCodeGeneration → bool
Check if this model supports code generation
no setter
supportsReasoning → bool
Check if this model supports reasoning/thinking
no setter
supportsToolCalling → bool
Check if this model supports tool calling
no setter
supportsVision → bool
Check if this model supports vision
no setter
systemPrompt → String?
final
temperature → double?
final
timeout → Duration?
final
toolChoice → ToolChoice?
final
tools → List<Tool>?
final
topK → int?
final
topP → double?
final

Methods

copyWith({String? apiKey, String? baseUrl, String? model, int? maxTokens, double? temperature, String? systemPrompt, Duration? timeout, double? topP, int? topK, List<Tool>? tools, ToolChoice? toolChoice}) → PhindConfig
getExtension<T>(String key) → T?
Get extension value from original config
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited