CapabilityValidationReport class

Validation report for provider capabilities

Constructors

CapabilityValidationReport({required bool isValid, required Set<LLMCapability> supported, required Set<LLMCapability> required, required Set<LLMCapability> missing, required Set<LLMCapability> extra})
const

Properties

extra → Set<LLMCapability>
final
hashCode → int
The hash code for this object.
no setterinherited
isValid → bool
final
missing → Set<LLMCapability>
final
required → Set<LLMCapability>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supported → Set<LLMCapability>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited