BaseProviderDioStrategy class abstract

Base implementation for common provider strategy patterns

Implemented types
Implementers

Constructors

BaseProviderDioStrategy()

Properties

hashCode → int
The hash code for this object.
no setterinherited
providerName → String
Provider name for logging and debugging
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildHeaders(dynamic config) → Map<String, String>
Build provider-specific HTTP headers
inherited
getBaseUrl(dynamic config) → String
Get base URL for the provider
override
getEnhancers(dynamic config) → List<DioEnhancer>
Get list of provider-specific enhancers
override
getTimeout(dynamic config) → Duration?
Get timeout configuration
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited