DioEnhancer class abstract

Interface for composable Dio enhancements

Enhancers can add interceptors, modify configuration, or apply other customizations to a Dio instance. They are applied in order and can be combined flexibly.

Implementers

Constructors

DioEnhancer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Enhancement name for debugging
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

enhance(Dio dio, dynamic config) → void
Apply enhancement to the Dio instance
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited