HeaderEnhancer class

Header-based enhancer for dynamic header modification

Implemented types

Constructors

HeaderEnhancer(Map<String, String> headerBuilder(dynamic config), String _name)

Properties

hashCode → int
The hash code for this object.
no setterinherited
headerBuilder → Map<String, String> Function(dynamic config)
final
name → String
Enhancement name for debugging
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

enhance(Dio dio, dynamic config) → void
Apply enhancement to the Dio instance
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited